@@ -7,6 +7,8 @@ from volsite_postgres_common.fn.function import Arg
 def sql__input_j_2_iid(att: str) -> str:
     return f"({Arg.input}->>'{att}')::TEXT"
 
+def sql__input_j_2_uuid(att: str) -> str:
+    return f"({Arg.input}->>'{att}')::UUID"
 
 def sql__input_j_2_bint_id(att: str) -> str:
     return f"{CFn.id_2_bigint}( ({Arg.input}->>'{att}')::TEXT )"
